#ifndef NT2_INCLUDE_CONSTANTS_C180_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_C180_HPP_INCLUDED

#include <nt2/constant/include/constants/c180.hpp>

#endif
